#
# spec file for package dfu-programmer
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2016 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           dfu-programmer
Version:        1.1.0
Release:        1.2
Summary:        A Device Firmware Update based USB programmer for Atmel chips
License:        GPL-2.0-or-later
Group:          Development/Tools/Other
Url:            http://dfu-programmer.sourceforge.net
Source:         https://github.com/dfu-programmer/dfu-programmer/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  automake
BuildRequires:  libusb-1_0-devel

%description
dfu-programmer is an implementation of the Device Firmware Upgrade class
USB driver that enables firmware upgrades for various USB enabled (with the
correct bootloader) Atmel chips. This program was created because the
Atmel "FLIP" program for flashing devices does not support flashing via USB
on Linux, and because standard DFU loaders do not work for Atmel's chips.

%prep
%setup -q

%build
./bootstrap.sh
%configure
%make_build

%install
%make_install

%check

%files
%doc AUTHORS NEWS README.md
%license COPYING
%{_bindir}/dfu-programmer
%{_mandir}/man1/%{name}.1*

%changelog
* Sun Oct 13 2024 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 1.1.0
  * Add --erase-first option #90 #92
  * Fix missing update-bash-completion.sh #91
  * Fix missing header files #93 #94
- Update to version 1.0.0
  * Remove libusb0 support
- Update to version 0.9.0
  * Add --validate-first and --ignore-outside options to the flash command
  * Disabled progress bar when not using a tty
- Update to version 0.8.1-libusb1
  * Fix bug preventing specifying a device with libusb0
  * Fix bug in order device id was printed with libusb0
  * Publish Windows binaries with libusb1
  * Update libusb1 include path
  * Update uses of deprecated libusb1 functions
- Update to version 0.8.1
  * Fix bug preventing specifying a device with libusb0
  * Fix bug in order device id was printed with libusb0
- Update to version 0.8.0
  * Experimental support for ST cortex M4
  * Enable GitHub Actions for releases [2022-10-13]
  * Make ./bootstrap.sh fail if any command fails (and print commands)
  * Update configure.ac features
  * Added IntelliSense hints for Visual Studio Code
- New source location (Github)
- Specfile update to current recommendations for Tumbleweed
* Tue Mar 22 2016 wk@ire.pw.edu.pl
- Update to version 0.7.2
  + Use the correct memory ranges for XMega.
    Bootloader space is additional to listed device size.
* Sun Jan  4 2015 p.drouand@gmail.com
- Update to version 0.7.1
  + Fix use of mandatory filename ChangeLog in distribution tarball
  + Fix infinite loop in rpl_malloc
  + Add experimental support for autocomplete on Ubuntu
  + Fix exit status of help-related options and improve start sequence
- Changes from version 0.7.0
  + Add support for atmega16c4 and atmega32c4
  + Fix device erase for bootloaders which return busy status
  + Better include file defaults for libusb when run bootstrap is run
    without pkgconfig.
  + Improved status output
  + Add hex dump commands
  + Add blank memory check
  + Major rework of the flash/user/eeprom code
  + Replace start and reset commands with launch
  + Repository and website migrated to GitHub
- Add pkg-config build require; needed to find libusb.h
* Sat Aug  2 2014 dmitry_r@opensuse.org
- spec file cleanup
- Use pkgconfig for build requires
* Tue Dec 17 2013 jw@suse.com
- updated to version 0.6.2
* Fri Jul  6 2012 mail.aroessler@gmail.com
- updated to version 0.5.4
* Wed Jun 10 2009 bernhard.walle@gmx.de
- Fix build for openSUSE 11.1.
* Sun Sep 30 2007 bwalle@suse.de
- initial package
